//Source file: CallFault.java
//Date: February 2007
//Generic Call Control for 1st draft ES 204 915-4-2 V1.1.1, DES/TISPAN-01032-04-2-OSA, Parlay 6.0

package org.csapi.jr.se.cc.gccs;

/**
 * Defines the cause of the call fault detected.
 *
 */
public final class CallFault implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static CallFault[] _array = new CallFault[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private CallFault(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _CALL_FAULT_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final CallFault CALL_FAULT_UNDEFINED = new CallFault(_CALL_FAULT_UNDEFINED);

    /**
     * This fault occurs when the final report has been sent to the application, but the application did not explicitly release or deassign the call object, within a specified time.
The timer value is operator specific.
     */
    public static final int _CALL_TIMEOUT_ON_RELEASE =  1;

    /**
     * This fault occurs when the final report has been sent to the application, but the application did not explicitly release or deassign the call object, within a specified time.
The timer value is operator specific.
     */
    public static final CallFault CALL_TIMEOUT_ON_RELEASE = new CallFault(_CALL_TIMEOUT_ON_RELEASE);

    /**
     * This fault occurs when the application did not instruct the gateway how to handle the call within a specified time, after the gateway reported an event that was requested by the application in interrupt mode.
The timer value is operator specific.
     */
    public static final int _CALL_TIMEOUT_ON_INTERRUPT =  2;

    /**
     * This fault occurs when the application did not instruct the gateway how to handle the call within a specified time, after the gateway reported an event that was requested by the application in interrupt mode.
The timer value is operator specific.
     */
    public static final CallFault CALL_TIMEOUT_ON_INTERRUPT = new CallFault(_CALL_TIMEOUT_ON_INTERRUPT);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved CallFault object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the CallFault object
     */
    public String getValueText() {
        switch (_value) {
            case _CALL_FAULT_UNDEFINED:
                return "CALL_FAULT_UNDEFINED";
            case _CALL_TIMEOUT_ON_RELEASE:
                return "CALL_TIMEOUT_ON_RELEASE";
            case _CALL_TIMEOUT_ON_INTERRUPT:
                return "CALL_TIMEOUT_ON_INTERRUPT";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static CallFault getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallFault)) {
            return false;
        }
        CallFault callFault = (CallFault) o; 
        if(!(this.getValue() == callFault.getValue())) {
            return false;
        }
        if (this.hashCode() != callFault.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallFault

